Introduction
============

.. include:: includes/all.rst

The ``debops-contrib.x2go_server`` role allows you to setup and mange
`X2Go`_ on the server-side.
X2Go enables you to access a graphical desktop of a computer over a low
bandwidth (or high bandwidth) connection.

Installation
~~~~~~~~~~~~

This role requires at least Ansible ``v2.1.3``. To install it, run::

    ansible-galaxy install debops-contrib.x2go_server

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
